# ListActiveUsersResponse

Response object for active users query
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active_users** | [**list[TimeIntervalMetrics]**](TimeIntervalMetrics.md) | Active user metrics per time interval | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


